@@ -37,6 +37,16 @@ def apply(op, col1, col2, col3):
     pipeout(df)
 
 
+@register
+def normalize(col=None):
+    df = pipein()
+    if col is None:
+        df = (df - df.min()) / (df.max() - df.min())
+    else:
+        df[col] = (df[col] - df[col].min()) / (df[col].max() - df[col].min())
+    pipeout(df)
+
+
 @register
 def date(col):
     df = pipein()
